.. _mainindex:

.. FitBenchmarking documentation master file, created by
   sphinx-quickstart on Wed Sep 11 09:17:28 2019.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

###########################################
Welcome to FitBenchmarking's documentation!
###########################################

.. mdinclude:: ../../README.md

Table Of Contents
-----------------
  
.. toctree::
   :maxdepth: 2
   :titlesonly:

   Concept <concept/index>
   Users <users/index>
   Extending <extending/index>
   Contributors <contributors/index>



